<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="lv">
<context>
    <name>AsciiFile</name>
    <message>
        <source>Read ascii points</source>
        <translation>Lasīt ascii punktus</translation>
    </message>
</context>
<context>
    <name>ImportShp</name>
    <message>
        <source>Import ESRI Shapefile</source>
        <translation>Importēt ESRI figūru datni</translation>
    </message>
</context>
<context>
    <name>LC_Align</name>
    <message>
        <source>Align</source>
        <translation>Līdzināt</translation>
    </message>
    <message>
        <source>first base point:</source>
        <translation>pirmais bāzes punkts:</translation>
    </message>
    <message>
        <source>first target point:</source>
        <translation>pirmais mērķa punkts:</translation>
    </message>
    <message>
        <source>second base point:</source>
        <translation>otrais bāzes punkts:</translation>
    </message>
    <message>
        <source>second target point:</source>
        <translation>otrais mērķa punkts:</translation>
    </message>
</context>
<context>
    <name>LC_List</name>
    <message>
        <source>List entities</source>
        <translation>Objektu saraksts</translation>
    </message>
    <message>
        <source>n</source>
        <translation>n</translation>
    </message>
    <message>
        <source>Empty Entity</source>
        <translation>Tukšs objekts</translation>
    </message>
    <message>
        <source>X</source>
        <translation>X</translation>
    </message>
    <message>
        <source>Y</source>
        <translation>
            </translation>
    </message>
    <message>
        <source>Layer</source>
        <translation>Slānis</translation>
    </message>
    <message>
        <source>Color</source>
        <translation>Krāsa</translation>
    </message>
    <message>
        <source>Line type</source>
        <translation>Līnijas tips</translation>
    </message>
    <message>
        <source>Line thickness</source>
        <translation>Līnijas biezums</translation>
    </message>
    <message>
        <source>ID</source>
        <translation>ID</translation>
    </message>
    <message>
        <source>POINT</source>
        <translation>PUNKTS</translation>
    </message>
    <message>
        <source>in point</source>
        <translation>punktā</translation>
    </message>
    <message>
        <source>LINE</source>
        <translation>LĪNIJA</translation>
    </message>
    <message>
        <source>from point</source>
        <translation>no punkta</translation>
    </message>
    <message>
        <source>to point</source>
        <translation>uz punktu</translation>
    </message>
    <message>
        <source>length</source>
        <translation>garums</translation>
    </message>
    <message>
        <source>Angle in XY plane</source>
        <translation>Leņķis XY plaknē</translation>
    </message>
    <message>
        <source>Inc.</source>
        <translation>SIA</translation>
    </message>
    <message>
        <source>ARC</source>
        <translation>LOKS</translation>
    </message>
    <message>
        <source>center point</source>
        <translation>centra punkts</translation>
    </message>
    <message>
        <source>radius</source>
        <translation>rādiuss</translation>
    </message>
    <message>
        <source>initial angle</source>
        <translation>sākotnējais leņķis</translation>
    </message>
    <message>
        <source>final angle</source>
        <translation>beigu leņķis</translation>
    </message>
    <message>
        <source>CIRCLE</source>
        <translation>RIŅĶIS</translation>
    </message>
    <message>
        <source>circumference</source>
        <translation>perimetrs</translation>
    </message>
    <message>
        <source>area</source>
        <translation>laukums</translation>
    </message>
    <message>
        <source>ELLIPSE</source>
        <translation>ELIPSE</translation>
    </message>
    <message>
        <source>major axis</source>
        <translation>primārā ass</translation>
    </message>
    <message>
        <source>CONSTRUCTIONLINE</source>
        <translation>KONSTRUKCIJASLĪNIJA</translation>
    </message>
    <message>
        <source>OVERLAYBOX</source>
        <translation>PĀRKLĀJUMAKASTE</translation>
    </message>
    <message>
        <source>SOLID</source>
        <translation>VIENLAIDUS</translation>
    </message>
    <message>
        <source>MTEXT</source>
        <translation>VTEKSTS</translation>
    </message>
    <message>
        <source>TEXT</source>
        <translation>TEKSTS</translation>
    </message>
    <message>
        <source>INSERT</source>
        <translation>IEVIETOT</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nosaukums</translation>
    </message>
    <message>
        <source>Insertion point</source>
        <translation>Ievietošanas punkts</translation>
    </message>
    <message>
        <source>POLYLINE</source>
        <translation>LAUZTALĪNIJA</translation>
    </message>
    <message>
        <source>Closed</source>
        <translation>Aizvērts</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nē</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Jā</translation>
    </message>
    <message>
        <source>Vertices</source>
        <translation>Virsotnes</translation>
    </message>
    <message>
        <source>curvature</source>
        <translation type="obsolete">izliekums</translation>
    </message>
    <message>
        <source>IMAGE</source>
        <translation>ATTĒLS</translation>
    </message>
    <message>
        <source>SPLINE</source>
        <translation>SPLAINS</translation>
    </message>
    <message>
        <source>HATCH</source>
        <translation>SVĪTROJUMS</translation>
    </message>
    <message>
        <source>DIMLEADER</source>
        <translation>DIMNORĀDE</translation>
    </message>
    <message>
        <source>DIMALIGNED</source>
        <translation>DIMLĪDZINĀTS</translation>
    </message>
    <message>
        <source>DIMLINEAR</source>
        <translation>DIMLINEĀRS</translation>
    </message>
    <message>
        <source>DIMRADIAL</source>
        <translation>DIMRADIĀLS</translation>
    </message>
    <message>
        <source>DIMDIAMETRIC</source>
        <translation>DIMDIAMETRISKS</translation>
    </message>
    <message>
        <source>DIMANGULAR</source>
        <translation>DIMLEŅĶISKS</translation>
    </message>
    <message>
        <source>UNKNOWN</source>
        <translation>NEZINĀMS</translation>
    </message>
    <message>
        <source>SPLINEPOINTS</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LC_SameProp</name>
    <message>
        <source>Same properties</source>
        <translation>Tās pašas īpašības</translation>
    </message>
    <message>
        <source>select original entity:</source>
        <translation>izvēlieties sākotnējo objektu:</translation>
    </message>
    <message>
        <source>select entities to change</source>
        <translation>izvēlieties maināmos objektus</translation>
    </message>
</context>
<context>
    <name>LC_Sample</name>
    <message>
        <source>Sample plugin</source>
        <translation>Parauga spraudnis</translation>
    </message>
</context>
<context>
    <name>PicFile</name>
    <message>
        <source>Read PIC file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>import PIC file</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>dibPunto</name>
    <message>
        <source>Read ascii points</source>
        <translation>Lasīt ascii punktus</translation>
    </message>
    <message>
        <source>File...</source>
        <translation>Datne...</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Formāts:</translation>
    </message>
    <message>
        <source>Space Separator</source>
        <translation>Atstarpes atdalītājs</translation>
    </message>
    <message>
        <source>Tab Separator</source>
        <translation>Tabulācijas atdalītājs</translation>
    </message>
    <message>
        <source>Comma Separator</source>
        <translation>Komata atdalītājs</translation>
    </message>
    <message>
        <source>Space in Columns</source>
        <translation>Atstarpe kolonnās</translation>
    </message>
    <message>
        <source>*.odb for Psion 2</source>
        <translation>*.odb Psion 2</translation>
    </message>
    <message>
        <source>Connect points</source>
        <translation>Savienot punktus</translation>
    </message>
    <message>
        <source>2D Point</source>
        <translation>2D punkts</translation>
    </message>
    <message>
        <source>Draw 2D Point</source>
        <translation>Zīmēt 2D punktu</translation>
    </message>
    <message>
        <source>3D Point</source>
        <translation>3D punkts</translation>
    </message>
    <message>
        <source>Draw 3D Point</source>
        <translation>Zīmēt 3D punktu</translation>
    </message>
    <message>
        <source>Point Number</source>
        <translation>Punkta numurs</translation>
    </message>
    <message>
        <source>Draw point number</source>
        <translation>Zīmēt punkta numuru</translation>
    </message>
    <message>
        <source>Point Elevation</source>
        <translation>Punkta pacēlums</translation>
    </message>
    <message>
        <source>Draw point elevation</source>
        <translation>Zīmēt punkta pacēlumu</translation>
    </message>
    <message>
        <source>Point Code</source>
        <translation>Punkta kods</translation>
    </message>
    <message>
        <source>Draw point code</source>
        <translation>Zīmēt punkta kodu</translation>
    </message>
    <message>
        <source>Accept</source>
        <translation>Pieņemt</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Atcelt</translation>
    </message>
    <message>
        <source>Select file</source>
        <translation>Izvēlieties datni</translation>
    </message>
    <message>
        <source>Point 2D layer is empty</source>
        <translation>Punkta 2D slānis ir tukšs</translation>
    </message>
    <message>
        <source>Point 3D layer is empty</source>
        <translation>Punkta 3D slānis ir tukšs</translation>
    </message>
    <message>
        <source>Point elevation layer is empty</source>
        <translation>Punkta pacēluma slānis ir tukšs</translation>
    </message>
    <message>
        <source>Point elevation height is empty</source>
        <translation>Punkta pacēluma augstums ir tukšs</translation>
    </message>
    <message>
        <source>Point elevation separation is empty</source>
        <translation>Punkta pacēluma atdalīšana ir tukša</translation>
    </message>
    <message>
        <source>Point number layer is empty</source>
        <translation>Punkta numura slānis ir tukšs</translation>
    </message>
    <message>
        <source>Point number height is empty</source>
        <translation>Punkta numura augstums ir tukšs</translation>
    </message>
    <message>
        <source>Point number separation is empty</source>
        <translation>Punkta skaitļa atdalīšana ir tukša</translation>
    </message>
    <message>
        <source>Point code layer is empty</source>
        <translation>Punkta koda slānis ir tukšs</translation>
    </message>
    <message>
        <source>Point code height is empty</source>
        <translation>Punkta koda augstums ir tukšs</translation>
    </message>
    <message>
        <source>Point code separation is empty</source>
        <translation>Punkta koda atdalīšana ir tukša</translation>
    </message>
    <message>
        <source>The file %1 not exist</source>
        <translation>Datne %1 neeksistē</translation>
    </message>
    <message>
        <source>Can&apos;t open the file %1</source>
        <translation>Nevar atvērt datni %1</translation>
    </message>
</context>
<context>
    <name>dibSHP</name>
    <message>
        <source>File...</source>
        <translation>Datne...</translation>
    </message>
    <message>
        <source>File type:</source>
        <translation>Datnes tips:</translation>
    </message>
    <message>
        <source>Layer</source>
        <translation>Slānis</translation>
    </message>
    <message>
        <source>Import ESRI Shapefile</source>
        <translation>Importēt ESRI figūru datni</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Nezināms</translation>
    </message>
    <message>
        <source>Current</source>
        <translation>Pašreizējais</translation>
    </message>
    <message>
        <source>From data:</source>
        <translation>No datiem:</translation>
    </message>
    <message>
        <source>Color</source>
        <translation>Krāsa</translation>
    </message>
    <message>
        <source>Line type</source>
        <translation>Līnijas tips</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>Platums</translation>
    </message>
    <message>
        <source>Point</source>
        <translation>Punkts</translation>
    </message>
    <message>
        <source>as Point</source>
        <translation>kā punkts</translation>
    </message>
    <message>
        <source>as Label:</source>
        <translation>kā etiķete:</translation>
    </message>
    <message>
        <source>Accept</source>
        <translation>Pieņemt</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Atcelt</translation>
    </message>
    <message>
        <source>Select file</source>
        <translation>Izvēlieties datni</translation>
    </message>
    <message>
        <source>Point+Measure</source>
        <translation>Punkts + mērs</translation>
    </message>
    <message>
        <source>3D Point</source>
        <translation>3D punkts</translation>
    </message>
    <message>
        <source>Multi Point</source>
        <translation>Vairāki punkti</translation>
    </message>
    <message>
        <source>Multi Point+Measure</source>
        <translation>Vairāki punkti + mērs</translation>
    </message>
    <message>
        <source>3D Multi Point</source>
        <translation>3D vairāki punkti</translation>
    </message>
    <message>
        <source>Arc</source>
        <translation>Loks</translation>
    </message>
    <message>
        <source>Arc+Measure</source>
        <translation>Loks + mērs</translation>
    </message>
    <message>
        <source>3D Arc</source>
        <translation>3D loks</translation>
    </message>
    <message>
        <source>Poligon</source>
        <translation type="obsolete">Daudzstūris</translation>
    </message>
    <message>
        <source>Poligon+Measure</source>
        <translation type="obsolete">Daudzstūris + mērs</translation>
    </message>
    <message>
        <source>3D Poligon</source>
        <translation type="obsolete">3D daudzstūris</translation>
    </message>
    <message>
        <source>Multipatch</source>
        <translation>Vairāku posmu</translation>
    </message>
    <message>
        <source>The file %1 not have extension .shp</source>
        <translation>Datnei %1 nav paplašinājuma .shp</translation>
    </message>
    <message>
        <source>The file %1 not exist</source>
        <translation>Datne %1 neeksistē</translation>
    </message>
    <message>
        <source>Polygon</source>
        <translation>Daudzstūris</translation>
    </message>
    <message>
        <source>Polygon+Measure</source>
        <translation>Daudzstūris + mērs</translation>
    </message>
    <message>
        <source>3D Polygon</source>
        <translation>3D daudzstūris</translation>
    </message>
</context>
<context>
    <name>lc_Listdlg</name>
    <message>
        <source>List entities</source>
        <translation>Objektu saraksts</translation>
    </message>
</context>
<context>
    <name>lc_Sampledlg</name>
    <message>
        <source>Draw line</source>
        <translation>Zīmēt līniju</translation>
    </message>
    <message>
        <source>Start X:</source>
        <translation>Sākuma X:</translation>
    </message>
    <message>
        <source>Start Y:</source>
        <translation>Sākuma Y:</translation>
    </message>
    <message>
        <source>End X:</source>
        <translation>Beigu X:</translation>
    </message>
    <message>
        <source>End Y:</source>
        <translation>Beigu Y:</translation>
    </message>
    <message>
        <source>Accept</source>
        <translation>Pieņemt</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Atcelt</translation>
    </message>
    <message>
        <source>Start X is empty</source>
        <translation>Sākuma X ir tukšs</translation>
    </message>
    <message>
        <source>Start Y is empty</source>
        <translation>Sākuma Y ir tukšs</translation>
    </message>
    <message>
        <source>End X is empty</source>
        <translation>Beigu X ir tukšs</translation>
    </message>
    <message>
        <source>End Y is empty</source>
        <translation>Beigu Y ir tukšs</translation>
    </message>
    <message>
        <source>Sample plugin</source>
        <translation>Parauga spraudnis</translation>
    </message>
</context>
<context>
    <name>picPunto</name>
    <message>
        <source>File...</source>
        <translation type="unfinished">Datne...</translation>
    </message>
    <message>
        <source>Scale:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Accept</source>
        <translation type="unfinished">Pieņemt</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Atcelt</translation>
    </message>
    <message>
        <source>Select file</source>
        <translation type="unfinished">Izvēlieties datni</translation>
    </message>
    <message>
        <source>Scale Factor is empty or invalid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The file %1 not exist</source>
        <translation type="unfinished">Datne %1 neeksistē</translation>
    </message>
    <message>
        <source>Can&apos;t open the file %1</source>
        <translation type="unfinished">Nevar atvērt datni %1</translation>
    </message>
    <message>
        <source>%1 objects imported</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>picPunto drawLine: first point is empty %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>picPunto drawLine: next point is empty %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>format error in %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>plot</name>
    <message>
        <source>Plot plugin</source>
        <translation>Grafiku spraudnis</translation>
    </message>
    <message>
        <source>Draw</source>
        <translation>Zīmēt</translation>
    </message>
</context>
<context>
    <name>plotDialog</name>
    <message>
        <source>Plot equation</source>
        <translation>Grafika vienādojums</translation>
    </message>
    <message>
        <source>This plugin allows you to plot mathematical equations.
If you don&apos;t want to use the parametric form, just leave out &quot;Equation2&quot;.
You can use pi when you need the value of pi (i.e. (3*pi)).
Use t or x in your equation as a variable/parameter.
</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Equation 1:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Equation 2:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>start value:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>end value:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>step size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Draw</source>
        <translation type="unfinished">Zīmēt</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Atcelt</translation>
    </message>
    <message>
        <source>Line Segments</source>
        <comment>Plot Equation to generate RS_Line segments</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Polyline</source>
        <comment>Plot Equation to generate RS_Polyline</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SplinePoints</source>
        <comment>Plot Equation to generate 2nd spline by LC_SplinePoints</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>pointBox</name>
    <message>
        <source>Layer:</source>
        <translation>Slānis:</translation>
    </message>
</context>
<context>
    <name>textBox</name>
    <message>
        <source>Style:</source>
        <translation>Stils:</translation>
    </message>
    <message>
        <source>Heigth:</source>
        <translation type="obsolete">Augstums:</translation>
    </message>
    <message>
        <source>Separation</source>
        <translation>Atdalīšana</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Augstums:</translation>
    </message>
</context>
</TS>
